@@ -13,8 +13,8 @@ Usage::
 """
 from typing import Any, Dict, Type
 
+from boto3.botocore_stubs import ClientError as BotocoreClientError
 from botocore.client import ClientMeta
-from botocore.exceptions import ClientError as Boto3ClientError
 
 from mypy_boto3_ec2_instance_connect.type_defs import SendSSHPublicKeyResponseTypeDef
 
@@ -22,17 +22,17 @@ __all__ = ("EC2InstanceConnectClient",)
 
 
 class Exceptions:
-    AuthException: Type[Boto3ClientError]
-    ClientError: Type[Boto3ClientError]
-    EC2InstanceNotFoundException: Type[Boto3ClientError]
-    InvalidArgsException: Type[Boto3ClientError]
-    ServiceException: Type[Boto3ClientError]
-    ThrottlingException: Type[Boto3ClientError]
+    AuthException: Type[BotocoreClientError]
+    ClientError: Type[BotocoreClientError]
+    EC2InstanceNotFoundException: Type[BotocoreClientError]
+    InvalidArgsException: Type[BotocoreClientError]
+    ServiceException: Type[BotocoreClientError]
+    ThrottlingException: Type[BotocoreClientError]
 
 
 class EC2InstanceConnectClient:
     """
-    [EC2InstanceConnect.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client)
+    [EC2InstanceConnect.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client)
     """
 
     meta: ClientMeta
@@ -40,7 +40,7 @@ class EC2InstanceConnectClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.can_paginate)
         """
 
     def generate_presigned_url(
@@ -51,12 +51,12 @@ class EC2InstanceConnectClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.generate_presigned_url)
         """
 
     def send_ssh_public_key(
         self, InstanceId: str, InstanceOSUser: str, SSHPublicKey: str, AvailabilityZone: str
     ) -> SendSSHPublicKeyResponseTypeDef:
         """
-        [Client.send_ssh_public_key documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.send_ssh_public_key)
+        [Client.send_ssh_public_key documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.send_ssh_public_key)
         """
